        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 23 <strong>control</strong><br>0,1,2,10,13,14,15,21,23,24,25,28,31,32,34,36,37,42,44,45,47,48,50';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <br>3,4,7,16,19,20,26,29,30,35,39,40,41,43,46';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 13 <br>5,6,8,9,11,12,17,18,22,27,33,38,49';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 23 <strong>control</strong><br>0,1,2,10,13,14,15,21,23,24,25,28,31,32,34,36,37,42,44,45,47,48,50';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <br>3,4,7,16,19,20,26,29,30,35,39,40,41,43,46';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 13 <br>5,6,8,9,11,12,17,18,22,27,33,38,49';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 23 <strong>control</strong><br>0,1,2,10,13,14,15,21,23,24,25,28,31,32,34,36,37,42,44,45,47,48,50';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <br>3,4,7,16,19,20,26,29,30,35,39,40,41,43,46';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 13 <br>5,6,8,9,11,12,17,18,22,27,33,38,49';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 23 <strong>control</strong><br>0,1,2,10,13,14,15,21,23,24,25,28,31,32,34,36,37,42,44,45,47,48,50';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <br>3,4,7,16,19,20,26,29,30,35,39,40,41,43,46';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 13 <br>5,6,8,9,11,12,17,18,22,27,33,38,49';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 23 <strong>control</strong><br>0,1,2,10,13,14,15,21,23,24,25,28,31,32,34,36,37,42,44,45,47,48,50';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <br>3,4,7,16,19,20,26,29,30,35,39,40,41,43,46';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 13 <br>5,6,8,9,11,12,17,18,22,27,33,38,49';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 23 <strong>control</strong><br>0,1,2,10,13,14,15,21,23,24,25,28,31,32,34,36,37,42,44,45,47,48,50';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <br>3,4,7,16,19,20,26,29,30,35,39,40,41,43,46';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 13 <br>5,6,8,9,11,12,17,18,22,27,33,38,49';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 23 <strong>control</strong><br>0,1,2,10,13,14,15,21,23,24,25,28,31,32,34,36,37,42,44,45,47,48,50';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <br>3,4,7,16,19,20,26,29,30,35,39,40,41,43,46';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 12 a 24 UTC (mm)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 13 <br>5,6,8,9,11,12,17,18,22,27,33,38,49';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 23 <strong>control</strong><br>0,1,2,10,13,14,15,21,23,24,25,28,31,32,34,36,37,42,44,45,47,48,50';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <br>3,4,7,16,19,20,26,29,30,35,39,40,41,43,46';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 12 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 13 <br>5,6,8,9,11,12,17,18,22,27,33,38,49';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>1</strong> representante: <strong>21</strong> miembros: 23 <strong>control</strong><br>0,1,2,10,13,14,15,21,23,24,25,28,31,32,34,36,37,42,44,45,47,48,50';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>2</strong> representante: <strong>16</strong> miembros: 15 <br>3,4,7,16,19,20,26,29,30,35,39,40,41,43,46';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260617 a 00</strong> UTC HH+090 (rango:084-096)<br>grupo: <strong>3</strong> representante: <strong>18</strong> miembros: 13 <br>5,6,8,9,11,12,17,18,22,27,33,38,49';}
}
